==> dfb++_0.9.25.orig.tar.gz: DFB++-0.9.25/dfb++/idirectfbscreen.cpp <==
/*
   (c) Copyright 2000-2002  convergence integrated media GmbH.
   All rights reserved.

   Written by Denis Oliver Kropp <dok@convergence.de>,
              Andreas Hundt <andi@convergence.de> and
              Sven Neumann <sven@convergence.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include "dfb++.h"
#include "dfb++_internal.h"

IDirectFBScreen::IDirectFBScreen(IDirectFBScreen_C *idirectfbscreen)
{
     refs  = 1;
     iface = idirectfbscreen;
}

IDirectFBScreen::~IDirectFBScreen()
{
}

IDirectFBScreen *IDirectFBScreen::AddRef()
{
     DFBCHECK( iface->AddRef (iface) );

     refs++;

     return this;
}

void IDirectFBScreen::Release()
{
     DFBCHECK( iface->Release (iface) );

     if (--refs == 0)
          delete this;
}

DFBScreenID IDirectFBScreen::GetID()
{
     DFBScreenID screen_id;

     DFBCHECK( iface->GetID (iface, &screen_id) );

     return screen_id;
}

DFBScreenDescription IDirectFBScreen::GetDescription()
{
     DFBScreenDescription desc;

     DFBCHECK( iface->GetDescription (iface, &desc) );

     return desc;
}

void IDirectFBScreen::EnumDisplayLayers (DFBDisplayLayerCallback  callback,
                                         void                    *callbackdata)
{
     DFBCHECK( iface->EnumDisplayLayers (iface, callback, callbackdata) );
}

void IDirectFBScreen::WaitForSync()
{
     DFBCHECK( iface->WaitForSync (iface) );
}

void IDirectFBScreen::SetPowerMode (DFBScreenPowerMode mode)
{
     DFBCHECK( iface->SetPowerMode (iface, mode) );
}


void IDirectFBScreen::GetMixerDescriptions (DFBScreenMixerDescription *descriptions)
{
     DFBCHECK( iface->GetMixerDescriptions (iface, descriptions) );
}

void IDirectFBScreen::GetMixerConfiguration (int                   mixer,
                                             DFBScreenMixerConfig *config)
{
     DFBCHECK( iface->GetMixerConfiguration (iface, mixer, config) );
}

void IDirectFBScreen::TestMixerConfiguration (int                         mixer,
                                              const DFBScreenMixerConfig &config,
                                              DFBScreenMixerConfigFlags  *failed)
{
     DFBCHECK( iface->TestMixerConfiguration (iface, mixer, &config, failed) );
}

void IDirectFBScreen::SetMixerConfiguration (int                         mixer,
                                             const DFBScreenMixerConfig &config)
{
     DFBCHECK( iface->SetMixerConfiguration (iface, mixer, &config) );
}


void IDirectFBScreen::GetEncoderDescriptions (DFBScreenEncoderDescription *descriptions)
{
     DFBCHECK( iface->GetEncoderDescriptions (iface, descriptions) );
}

void IDirectFBScreen::GetEncoderConfiguration (int                     encoder,
                                               DFBScreenEncoderConfig *config)
{
     DFBCHECK( iface->GetEncoderConfiguration (iface, encoder, config) );
}

void IDirectFBScreen::TestEncoderConfiguration (int                           encoder,
                                                const DFBScreenEncoderConfig &config,
                                                DFBScreenEncoderConfigFlags  *failed)
{
     DFBCHECK( iface->TestEncoderConfiguration (iface, encoder, &config, failed) );
}

void IDirectFBScreen::SetEncoderConfiguration (int                           encoder,
                                               const DFBScreenEncoderConfig &config)
{
     DFBCHECK( iface->SetEncoderConfiguration (iface, encoder, &config) );
}


void IDirectFBScreen::GetOutputDescriptions (DFBScreenOutputDescription *descriptions)
{
     DFBCHECK( iface->GetOutputDescriptions (iface, descriptions) );
}

void IDirectFBScreen::GetOutputConfiguration (int                    output,
                                              DFBScreenOutputConfig *config)
{
     DFBCHECK( iface->GetOutputConfiguration (iface, output, config) );
}

void IDirectFBScreen::TestOutputConfiguration (int                          output,
                                               const DFBScreenOutputConfig &config,
                                               DFBScreenOutputConfigFlags  *failed)
{
     DFBCHECK( iface->TestOutputConfiguration (iface, output, &config, failed) );
}

void IDirectFBScreen::SetOutputConfiguration (int                          output,
                                              const DFBScreenOutputConfig &config)
{
     DFBCHECK( iface->SetOutputConfiguration (iface, output, &config) );
}

==> dfb++_1.0.0.orig.tar.gz: DFB++-1.0.0/dfb++/idirectfbscreen.cpp <==
/*
   (c) Copyright 2000-2002  convergence integrated media GmbH.
   All rights reserved.

   Written by Denis Oliver Kropp <dok@convergence.de>,
              Andreas Hundt <andi@convergence.de> and
              Sven Neumann <sven@convergence.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include "dfb++.h"
#include "dfb++_internal.h"

IDirectFBScreen::IDirectFBScreen(IDirectFBScreen_C *idirectfbscreen)
{
     refs  = 1;
     iface = idirectfbscreen;
}

IDirectFBScreen::~IDirectFBScreen()
{
}

IDirectFBScreen *IDirectFBScreen::AddRef()
{
     DFBCHECK( iface->AddRef (iface) );

     refs++;

     return this;
}

void IDirectFBScreen::Release()
{
     DFBCHECK( iface->Release (iface) );

     if (--refs == 0)
          delete this;
}

DFBScreenID IDirectFBScreen::GetID()
{
     DFBScreenID screen_id;

     DFBCHECK( iface->GetID (iface, &screen_id) );

     return screen_id;
}

DFBScreenDescription IDirectFBScreen::GetDescription()
{
     DFBScreenDescription desc;

     DFBCHECK( iface->GetDescription (iface, &desc) );

     return desc;
}

void IDirectFBScreen::GetSize (int *width, 
                               int *height)
{
     DFBCHECK( iface->GetSize (iface, width, height) );
}

void IDirectFBScreen::EnumDisplayLayers (DFBDisplayLayerCallback  callback,
                                         void                    *callbackdata)
{
     DFBCHECK( iface->EnumDisplayLayers (iface, callback, callbackdata) );
}

void IDirectFBScreen::WaitForSync()
{
     DFBCHECK( iface->WaitForSync (iface) );
}

void IDirectFBScreen::SetPowerMode (DFBScreenPowerMode mode)
{
     DFBCHECK( iface->SetPowerMode (iface, mode) );
}


void IDirectFBScreen::GetMixerDescriptions (DFBScreenMixerDescription *descriptions)
{
     DFBCHECK( iface->GetMixerDescriptions (iface, descriptions) );
}

void IDirectFBScreen::GetMixerConfiguration (int                   mixer,
                                             DFBScreenMixerConfig *config)
{
     DFBCHECK( iface->GetMixerConfiguration (iface, mixer, config) );
}

void IDirectFBScreen::TestMixerConfiguration (int                         mixer,
                                              const DFBScreenMixerConfig &config,
                                              DFBScreenMixerConfigFlags  *failed)
{
     DFBCHECK( iface->TestMixerConfiguration (iface, mixer, &config, failed) );
}

void IDirectFBScreen::SetMixerConfiguration (int                         mixer,
                                             const DFBScreenMixerConfig &config)
{
     DFBCHECK( iface->SetMixerConfiguration (iface, mixer, &config) );
}


void IDirectFBScreen::GetEncoderDescriptions (DFBScreenEncoderDescription *descriptions)
{
     DFBCHECK( iface->GetEncoderDescriptions (iface, descriptions) );
}

void IDirectFBScreen::GetEncoderConfiguration (int                     encoder,
                                               DFBScreenEncoderConfig *config)
{
     DFBCHECK( iface->GetEncoderConfiguration (iface, encoder, config) );
}

void IDirectFBScreen::TestEncoderConfiguration (int                           encoder,
                                                const DFBScreenEncoderConfig &config,
                                                DFBScreenEncoderConfigFlags  *failed)
{
     DFBCHECK( iface->TestEncoderConfiguration (iface, encoder, &config, failed) );
}

void IDirectFBScreen::SetEncoderConfiguration (int                           encoder,
                                               const DFBScreenEncoderConfig &config)
{
     DFBCHECK( iface->SetEncoderConfiguration (iface, encoder, &config) );
}


void IDirectFBScreen::GetOutputDescriptions (DFBScreenOutputDescription *descriptions)
{
     DFBCHECK( iface->GetOutputDescriptions (iface, descriptions) );
}

void IDirectFBScreen::GetOutputConfiguration (int                    output,
                                              DFBScreenOutputConfig *config)
{
     DFBCHECK( iface->GetOutputConfiguration (iface, output, config) );
}

void IDirectFBScreen::TestOutputConfiguration (int                          output,
                                               const DFBScreenOutputConfig &config,
                                               DFBScreenOutputConfigFlags  *failed)
{
     DFBCHECK( iface->TestOutputConfiguration (iface, output, &config, failed) );
}

void IDirectFBScreen::SetOutputConfiguration (int                          output,
                                              const DFBScreenOutputConfig &config)
{
     DFBCHECK( iface->SetOutputConfiguration (iface, output, &config) );
}
